==> kubernetes-model-flowcontrol-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta2/FlowSchemaStatusFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface FlowSchemaStatusFluent<A extends FlowSchemaStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(Integer index,FlowSchemaCondition item);
  public A setToConditions(Integer index,FlowSchemaCondition item);
  public A addToConditions(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.FlowSchemaCondition... items);
  public A addAllToConditions(Collection<FlowSchemaCondition> items);
  public A removeFromConditions(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.FlowSchemaCondition... items);
  public A removeAllFromConditions(Collection<FlowSchemaCondition> items);
  public A removeMatchingFromConditions(Predicate<FlowSchemaConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<FlowSchemaCondition> getConditions();
  public List<FlowSchemaCondition> buildConditions();
  public FlowSchemaCondition buildCondition(Integer index);
  public FlowSchemaCondition buildFirstCondition();
  public FlowSchemaCondition buildLastCondition();
  public FlowSchemaCondition buildMatchingCondition(Predicate<FlowSchemaConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<FlowSchemaConditionBuilder> predicate);
  public A withConditions(List<FlowSchemaCondition> conditions);
  public A withConditions(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.FlowSchemaCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
  public FlowSchemaStatusFluent.ConditionsNested<A> addNewCondition();
  public FlowSchemaStatusFluent.ConditionsNested<A> addNewConditionLike(FlowSchemaCondition item);
  public FlowSchemaStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,FlowSchemaCondition item);
  public FlowSchemaStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public FlowSchemaStatusFluent.ConditionsNested<A> editFirstCondition();
  public FlowSchemaStatusFluent.ConditionsNested<A> editLastCondition();
  public FlowSchemaStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<FlowSchemaConditionBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ConditionsNested<N> extends Nested<N>,FlowSchemaConditionFluent<FlowSchemaStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}

==> kubernetes-model-flowcontrol-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta2/FlowSchemaStatusFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface FlowSchemaStatusFluent<A extends FlowSchemaStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(int index,FlowSchemaCondition item);
  public A setToConditions(int index,FlowSchemaCondition item);
  public A addToConditions(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.FlowSchemaCondition... items);
  public A addAllToConditions(Collection<FlowSchemaCondition> items);
  public A removeFromConditions(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.FlowSchemaCondition... items);
  public A removeAllFromConditions(Collection<FlowSchemaCondition> items);
  public A removeMatchingFromConditions(Predicate<FlowSchemaConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<FlowSchemaCondition> getConditions();
  public List<FlowSchemaCondition> buildConditions();
  public FlowSchemaCondition buildCondition(int index);
  public FlowSchemaCondition buildFirstCondition();
  public FlowSchemaCondition buildLastCondition();
  public FlowSchemaCondition buildMatchingCondition(Predicate<FlowSchemaConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<FlowSchemaConditionBuilder> predicate);
  public A withConditions(List<FlowSchemaCondition> conditions);
  public A withConditions(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.FlowSchemaCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
  public FlowSchemaStatusFluent.ConditionsNested<A> addNewCondition();
  public FlowSchemaStatusFluent.ConditionsNested<A> addNewConditionLike(FlowSchemaCondition item);
  public FlowSchemaStatusFluent.ConditionsNested<A> setNewConditionLike(int index,FlowSchemaCondition item);
  public FlowSchemaStatusFluent.ConditionsNested<A> editCondition(int index);
  public FlowSchemaStatusFluent.ConditionsNested<A> editFirstCondition();
  public FlowSchemaStatusFluent.ConditionsNested<A> editLastCondition();
  public FlowSchemaStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<FlowSchemaConditionBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ConditionsNested<N> extends Nested<N>,FlowSchemaConditionFluent<FlowSchemaStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}
